# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import OptionDef

class DvxClassInfo(DynamicData):
   deviceClass: ElementDescription
   vendorName: str
   sriovNic: bool
   configParams: list[OptionDef] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import binary
from pyVmomi.VmomiSupport import byte

from pyVmomi.vmodl import DynamicData

class HostSubSpecification(DynamicData):
   name: str
   createdTime: datetime
   data: list[byte] = []
   binaryData: Optional[binary] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.provider import Provider

from pyVmomi.vim.vm.replication import FaultDomainId

class FaultDomainProviderMapping(DynamicData):
   activeProvider: Provider
   faultDomainId: list[FaultDomainId] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vsan import DirectoryServerConfig

class ActiveDirectoryServerConfig(DirectoryServerConfig):
   activeDirectoryDomainName: Optional[str] = None
   username: Optional[str] = None
   password: Optional[str] = None
   organizationalUnit: Optional[str] = None
   preferredADServers: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.sms.provider import ProviderSpec

class VasaProviderSpec(ProviderSpec):
   username: str
   password: str
   url: str
   certificate: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanPerfMetricId
from pyVmomi.vim.cluster import VsanPerfThreshold

class VsanPerfMetricSeriesCSV(DynamicData):
   metricId: VsanPerfMetricId
   threshold: Optional[VsanPerfThreshold] = None
   numExceptions: Optional[str] = None
   values: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Network

from pyVmomi.vim.vm import TargetInfo

class NetworkInfo(TargetInfo):
   network: Network.Summary
   vswitch: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.pbm import ServiceInstanceContent

class ServiceInstance(ManagedObject):
   @property
   def content(self) -> ServiceInstanceContent: ...

   def RetrieveContent(self) -> ServiceInstanceContent: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.event import AlarmEvent
from pyVmomi.vim.event import ManagedEntityEventArgument

class AlarmEmailFailedEvent(AlarmEvent):
   entity: ManagedEntityEventArgument
   to: str
   reason: MethodFault



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanDatastoreDefaultPolicySelectionConfig
from pyVmomi.vim.vsan import VsanEsaDiskConfiguration

class VsanEsaConfigInfo(DynamicData):
   hclDiskClaimEnabled: Optional[bool] = None
   datastoreDefaultPolicySelectionConfig: Optional[VsanDatastoreDefaultPolicySelectionConfig] = None
   diskConfiguration: Optional[VsanEsaDiskConfiguration] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import TaskReason

from pyVmomi.vim.alarm import Alarm

class TaskReasonAlarm(TaskReason):
   alarmName: str
   alarm: Alarm
   entityName: str
   entity: ManagedEntity



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ProfileSpec

class VsanWhatifCapacity(DynamicData):
   totalWhatifCapacityB: long
   freeWhatifCapacityB: long
   storagePolicy: ProfileSpec
   isSatisfiable: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanWhatIfEvacDetail(DynamicData):
   success: Optional[bool] = None
   bytesToSync: Optional[long] = None
   inaccessibleObjects: list[str] = []
   incompliantObjects: list[str] = []
   extraSpaceNeeded: Optional[long] = None
   failedDueToInaccessibleObjects: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vmodl import MethodFault

class InvalidProperty(MethodFault):
   name: PropertyPath



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.dvs import DistributedVirtualPortgroup

from pyVmomi.vim.event import ChangesInfoEventArgument
from pyVmomi.vim.event import DVPortgroupEvent

class DVPortgroupReconfiguredEvent(DVPortgroupEvent):
   configSpec: DistributedVirtualPortgroup.ConfigSpec
   configChanges: Optional[ChangesInfoEventArgument] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VsanResourceConstraint

from pyVmomi.vmodl import KeyAnyValue

class VsanPropertyConstraint(VsanResourceConstraint):
   propertyName: Optional[str] = None
   comparator: Optional[str] = None
   comparableValue: Optional[KeyAnyValue] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterProactiveTestResult

from pyVmomi.vim.host import VsanHostVmdkLoadTestResult

class VsanClusterVmdkLoadTestResult(DynamicData):
   task: Optional[Task] = None
   clusterResult: Optional[VsanClusterProactiveTestResult] = None
   hostResults: list[VsanHostVmdkLoadTestResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import IODiagnosticsTarget

class IODiagnosticsInstanceEvent(DynamicData):
   eventType: str
   eventTime: datetime
   eventTargets: list[IODiagnosticsTarget] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cns import SnapshotId
from pyVmomi.vim.cns import VolumeId
from pyVmomi.vim.cns import VolumeSource

class SnapshotVolumeSource(VolumeSource):
   volumeId: Optional[VolumeId] = None
   snapshotId: Optional[SnapshotId] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan.host import ComplianceDetail

class ComplianceResult(DynamicData):
   checkTime: datetime
   policyId: Optional[str] = None
   policyGen: Optional[int] = None
   objComplianceDetail: list[ComplianceDetail] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import CpuIncompatible

class CpuIncompatible81EDX(CpuIncompatible):
   nx: bool
   ffxsr: bool
   rdtscp: bool
   lm: bool
   other: bool
   otherOnly: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.pbm.placement import MatchingResources

from pyVmomi.vim.vm.replication import ReplicationGroupId

class MatchingReplicationResources(MatchingResources):
   replicationGroup: list[ReplicationGroupId] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cns import ContainerCluster
from pyVmomi.vim.cns import EntityMetadata

class VolumeMetadata(DynamicData):
   containerCluster: ContainerCluster
   entityMetadata: list[EntityMetadata] = []
   containerClusterArray: list[ContainerCluster] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.fault import HostConnectFault

class MultipleCertificatesVerifyFault(HostConnectFault):
   class ThumbprintData(DynamicData):
      port: int
      thumbprint: str

   thumbprintData: list[ThumbprintData] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.device import VirtualDevice

class FaultToleranceVMConfigSpec(DynamicData):
   class FaultToleranceDiskSpec(DynamicData):
      disk: VirtualDevice
      datastore: Datastore

   vmConfig: Optional[Datastore] = None
   disks: list[FaultToleranceDiskSpec] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class DnsConfigSpec(DynamicData):
   dhcp: Optional[bool] = None
   hostName: Optional[str] = None
   domainName: Optional[str] = None
   ipAddress: list[str] = []
   searchDomain: list[str] = []
